#ifndef LCD_LIB_H
#define LCD_LIB_H

#include <avr/io.h>
#include <util/delay.h>

// Определяем порты для подключения LCD
#define LCD_PORT PORTB
#define LCD_DDR  DDRB
#define LCD_PIN  PINB

// Определяем выводы для управления
#define LCD_RS PB0
#define LCD_RW PB1
#define LCD_E  PB2

// Определяем выводы для данных
#define LCD_D4 PB4
#define LCD_D5 PB5
#define LCD_D6 PB6
#define LCD_D7 PB7

// Прототипы функций
void LCDinit(void);
void LCDsendCommand(uint8_t cmd);
void LCDsendChar(uint8_t ch);
void LCDclr(void);
void LCDGotoXY(uint8_t x, uint8_t y);
void LCDsend2digitNumber(int8_t num);
void LCDstring(uint8_t* str);

#endif // LCD_LIB_H
