#include <avr/io.h>//Подключаем библиотеку для микроконтроллера ATtiny2313
#include <util/delay.h>// Подключаем библиотеку функции задержки
#include <lcd_lib.h>//Подключаем библиотеку для LCD
#include <lcd_lib.c>//Подключаем библиотеку для LCD
int main(void)//главная функция программы
{ DDRB=0xff;//порт B как выход
  PORTB=0x00;// обнуляем регистр порта B
  LCDinit();//инициализируем LCD
  LCDclr();// очищаем дисплей LCD
  LCDGotoXY(0, 0);// переведем курсор в ячейку с координатой (0,0)
  LCDsendChar('K');//отправим символ в LCD
  _delay_ms(500); //подождем 500 мс
  LCDGotoXY(1, 0);
  _delay_ms(500);
  LCDsendChar('u');
  _delay_ms(500); 
  LCDGotoXY(2, 0);
  _delay_ms(500);
  LCDsendChar('b');
  _delay_ms(500); 
  LCDGotoXY(3, 0);
  _delay_ms(500);
  LCDsendChar('S');
  _delay_ms(500); 
  LCDGotoXY(4, 0);
  _delay_ms(500);
  LCDsendChar('U');
  _delay_ms(500); 
  LCDGotoXY(5, 0);
  _delay_ms(500);
	
	
}
	
  
